/*
	$Id: BatchedPropertyInfo.java 4889 2009-04-06 12:52:39Z nicklas $

	Copyright (C) 2006 Jari Häkkinen, Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core;

/**
	Holds information about a batchable property.

	@see net.sf.basedb.core.data.ExtendableData
	@author Nicklas
	@version 2.0
	@base.modified $Date: 2009-04-06 14:52:39 +0200 (må, 06 apr 2009) $
*/
public class BatchedPropertyInfo
{
	private final String name;
	private final int sqlTypeCode;

	/**
		Create a new extended property.
		See the getter methods for a description of the parameters.
	*/
	BatchedPropertyInfo(String name, int sqlTypeCode)
	{
		this.name = name;
		this.sqlTypeCode = sqlTypeCode;
	}

	/**
		Get the name of the property. This is the name that is
		used in queries.
		@return A string with the name
	*/
	public String getName()
	{
		return name;
	}
	/**
		Get the sql type code as defined by {@link java.sql.Types}.
		@return The type code
	*/
	public int getSqlTypeCode()
	{
		return sqlTypeCode;
	}
}

