/**
	$Id: SubtypableData.java 5818 2011-10-21 11:15:41Z nicklas $

	Copyright (C) 2011 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.data;

/**
	A subtypable item is an item that can have a subtype. Subtypes are defined
	by objects of the {@link ItemSubtypeData} class.
	<p>
	This interface defines Hibernate database mapping for the
	<code>itemSubtype</code> association to a column with
	the name <code>subtype_id</code>. If a subclass wants
	to map the association to another column, it should override
	the {@link #getItemSubtype()} method and add a Hibernate tag 
	in the comment.
	<p>
	
	<b>Reference implementation</b><br>
	<pre class="code">
private ItemSubtypeData subtype;
public ItemSubtypeData getItemSubtype()
{
   return subtype;
}
public void setItemSubtype(ItemSubtypeData subtype)
{
   this.subtype = subtype;
}
</pre>

	@author Nicklas
	@since 3.0
	@base.modified $Date: 2011-10-21 13:15:41 +0200 (fr, 21 okt 2011) $
	@see <a href="../../../../../../html/developer/api/data_api.platforms.html">Developer documentation: Experimental platforms and item subtypes</a>
*/
public interface SubtypableData
{

	/**
		Get the subtype of the item.
		@hibernate.many-to-one column="`subtype_id`" not-null="false" outer-join="false"
	*/
	public ItemSubtypeData getItemSubtype();
	
	/**
		Set the subtype of the item.
	*/
	public void setItemSubtype(ItemSubtypeData subtype);
	
}
