/**
	$Id: AnnotationSetterPlugin.java 4516 2008-09-11 20:09:17Z jari $

	Copyright (C) 2007 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.core.plugin;

import net.sf.basedb.core.AnnotationSet;
import net.sf.basedb.core.AnnotationType;
import net.sf.basedb.core.ItemQuery;

/**
	This is a interface that should be implemented by plug-ins that are setting
	annotations on items thy create or work with. By implementing this interface
	it will be possible to store annotations at the plugin definition and/or plugin
	configuration level for any item type. The plug-in must copy the annotation values
	itself.

	@author nicklas
	@version 2.5
	@base.modified $Date: 2008-09-11 22:09:17 +0200 (to, 11 sep 2008) $
	@see AnnotationSet#copyFrom(net.sf.basedb.core.Annotatable, boolean)
*/
public interface AnnotationSetterPlugin
	extends Plugin
{
	/**
		Create a query that returns the annotation types that can be used
		by the current plug-in. For example the {@link net.sf.basedb.plugins.RawDataFlatFileImporter} 
		plug-in can set annotations on the raw bioassay and thus return all annotation types
		that can be used on raw bioassays: <code>AnnotationType.getQuery(Item.RAWBIOASSAY)</code>.
		@return A query returning annotation types, or null if the current setup doesn't
			allow any annotations
	*/
	public ItemQuery<AnnotationType> getAnnotationTypes();

	/**
		Get a message that explains what the plug-in does with the annotations
		it has.
	
		@return A message or null
	*/
	public String getAnnotationMessage();
}
