/**
	$Id: BaseFileSectionParser.java 5590 2011-03-16 11:48:47Z nicklas $

	Copyright (C) 2009 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.basefile;

import java.io.IOException;

import net.sf.basedb.core.signal.ThreadSignalHandler;
import net.sf.basedb.util.parser.FlatFileParser;

/**
	A section parser is responsible for parsing and collecting data
	that is found in a section in a serial or matrix BASEfile. A
	section parser should check for user abort by calling {@link 
	ThreadSignalHandler#checkInterrupted()} at regular intervals. The parser
	should also update progress by calling {@link BaseFileParser#setProgress(long, String)}.
	Note that progress should be reported as the number of bytes parsed,
	which can simply can be retreived by calling {@link FlatFileParser#getParsedBytes()}.

	@author Nicklas
	@version 2.14
	@base.modified $Date: 2011-03-16 12:48:47 +0100 (on, 16 mar 2011) $
*/
public interface BaseFileSectionParser
{
	/**
		Parse the current section. The current parse position is right
		after the section marker. If the section contains headers the
		{@link FlatFileParser#parseHeaders()} must be called. Use 
		{@link FlatFileParser#nextData()} to parse data lines.
		
		@param parser The master BASEfile parser (can be used for
			reporting progress, checking for interrupts, etc.)
		@param ffp The actual file parser, use this to get the data
		@throws IOException If there is a problem reading the data
	*/
	public void parseSection(BaseFileParser parser, FlatFileParser ffp)
		throws IOException;
	
}
