/**
	$Id: ExtensionPointEventFilter.java 6875 2015-04-20 09:08:18Z nicklas $

	Copyright (C) 2008 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
*/
package net.sf.basedb.util.extensions.events;

import net.sf.basedb.util.extensions.Extension;
import net.sf.basedb.util.extensions.ExtensionPoint;

/**
	Event filter that only passes events for a specific extension point.

	@author nicklas
	@version 2.8
	@base.modified $Date: 2015-04-20 11:08:18 +0200 (må, 20 apr 2015) $
 */
public class ExtensionPointEventFilter
	implements EventFilter
{
	private final String id;
	
	/**
		Create a new extension point event filter.
		@param extensionPoint The extension point to pass events for
	*/
	public ExtensionPointEventFilter(ExtensionPoint<?> extensionPoint)
	{
		this.id = extensionPoint.getId();
	}
	
	/**
		Create a new extension point event filter
		@param id The ID of the extension point
	*/
	public ExtensionPointEventFilter(String id)
	{
		this.id = id;
	}
	
	/**
		@return TRUE if the extension point has the same ID as the one
			given in the constructor
	*/
	@Override
	public boolean shouldSend(EventType event, ExtensionPoint<?> extensionPoint,
			Extension<?> extension)
	{
		return id.equals(extensionPoint.getId());
	}

}
