/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var Protocols = function()
{
	var protocols = {};
	
	/**
		Initialize the page.
	*/
	protocols.initPage = function()
	{
		var pageId = Doc.getPageId();
		if (pageId == 'edit-page')
		{
			Buttons.addClickHandler('btnSave', protocols.save);
			Buttons.addClickHandler('close', App.closeWindow);
			
			// Tab validation
			TabControl.addTabActivateListener('settings.annotations', protocols.loadAnnotationsFrame);
			TabControl.addTabValidator('settings.info', protocols.validateProtocol);

			// Protocol parameters
			Buttons.addClickHandler('btnAddProtocolParameters', protocols.addProtocolParameters);
			Events.addEventHandler('btnAddProtocolParameters', 'base-selected', protocols.parameterSelected);

			// Select file
			Buttons.addClickHandler('file_id.select', protocols.selectFile);
			Events.addEventHandler('file_id', 'base-selected', Items.onItemSelected);

			// Subtype
			Events.addEventHandler('subtype_id', 'change', protocols.subtypeOnChange);
			protocols.subtypeOnChange();	
		}
		else if (pageId == 'view-page')
		{
			var itemId = Data.get('page-data', 'item-id');
			var attributes = {'item-type': 'PROTOCOL', 'item-id': itemId};
			Buttons.addClickHandler('btnEdit', Buttons.editItem, attributes);
			Buttons.addClickHandler('btnDelete', Buttons.deleteItem, attributes);
			Buttons.addClickHandler('btnRestore', Buttons.restoreItem, attributes);
			Buttons.addClickHandler('btnUsingItems', Buttons.showUsingItems, attributes);
			Buttons.addClickHandler('btnDeletePermanently', Buttons.deleteItemPermanently, attributes);
			Buttons.addClickHandler('btnShare', Buttons.shareItem, attributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwner, attributes);
			Buttons.addClickHandler('btnExport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnImport', Buttons.runPlugin, attributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runPlugin, attributes);
			
			TabControl.addTabActivateListener('main.annotations', AnnotationsList.loadOnce);
			TabControl.addTabActivateListener('main.history', History.loadOnce);
		}
		else if (pageId == 'list-page')
		{
			var attributes = {'item-type': 'PROTOCOL'};
			var tableAttributes = {'table-id': 'protocols'};
			Buttons.addClickHandler('btnNewItem', Buttons.newItem, attributes);
			Buttons.addClickHandler('btnDeleteItems', Buttons.deleteItems, tableAttributes);
			Buttons.addClickHandler('btnRestoreItems', Buttons.restoreItems, tableAttributes);
			Buttons.addClickHandler('btnShareItems', Buttons.shareItems, tableAttributes);
			Buttons.addClickHandler('btnSetOwner', Buttons.setOwnerOfItems, tableAttributes);
			Buttons.addClickHandler('btnColumns', Buttons.configureColumns, tableAttributes);
			Buttons.addClickHandler('btnExport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnImport', Buttons.runListPlugin, tableAttributes);
			Buttons.addClickHandler('btnRunPlugin', Buttons.runListPlugin, tableAttributes);

			Buttons.addClickHandler('close', App.closeWindow);
			Buttons.addClickHandler('btnOk', Buttons.returnSelected, tableAttributes);
		}
	}
	
	// Submit the form
	protocols.save = function()
	{
		var frm = document.forms['protocol'];
		if (TabControl.validateActiveTab('settings'))
		{
			Annotations.saveModifiedAnnotationsToForm(frm);
			Link.exportActions('annotationTypes');
			frm.submit();
		}
	}

	protocols.validateProtocol = function()
	{
		var frm = document.forms['protocol'];
		if (Strings.trim(frm.name.value) == '')
		{
			Forms.showNotification(frm.name, 'You must enter a name');
			return false;
		}
		return true;
	}

	protocols.loadAnnotationsFrame = function()
	{
		Annotations.autoLoadEditFrame(null, ItemSubtype.getSubtypeId('subtype_id'));
	}

	
	/**
		Open a popup dialog for selecting protocol parameters.
	*/
	protocols.addProtocolParameters = function(event)
	{
		var frm = document.forms['protocol'];
		var currentParameters = Link.getIdsInList(frm.annotationTypes, 'ANNOTATIONTYPE');
		var excludes = currentParameters.join(',');
		var url = '&resetTemporary=1&tmpfilter:BOOLEAN:protocolParameter=true';
		url += "&exclude="+excludes;
		Dialogs.selectItem('ANNOTATIONTYPE', event.currentTarget.id, 1, url);
	}
	
	/**
		Callback for adding selected protocol parameters to the list.
	 */
	protocols.parameterSelected = function(event)
	{
		Link.addItem('annotationTypes', 'ANNOTATIONTYPE', event.detail);
	}

	/**
		Select the file with protocol details.
	 */
	protocols.selectFile = function()
	{
		var frm = document.forms['protocol'];
		var url = '&resetTemporary=1';
		url += ItemSubtype.createRelatedFilter('subtype_id', 'FILE', Data.int('page-data', 'protocol-filetype-id'));
		if (frm.file_id.length > 1) 
		{
			var id = Math.abs(parseInt(frm.file_id[1].value));
			url += '&item_id='+id;
		}
		Dialogs.selectItem('FILE', 'file_id', 0, url);
	}
	
	
	protocols.subtypeOnChange = function()
	{
		var frm = document.forms['protocol'];
		if (frm.replaceExistingDefault)
		{
			var subtypeId = ItemSubtype.getSubtypeId('subtype_id');
			var defaultInfo = ItemSubtype.getProjectDefaultAndRecentItems('PROTOCOL', subtypeId);
			var currentDefaultDiv = Doc.element('currentDefault');
			
			var tooltip = '';
			var html = '';
			var checked = true;
			var disabled = false;
			
			var numDefaults = defaultInfo['default'] ? defaultInfo['default'].length : 0;
			if (numDefaults == 1)
			{
				html = '('+Strings.encodeTags(Strings.cut(defaultInfo['default'][0].name, 40)) + ')';
			}
			else if (numDefaults == 0)
			{
				html = '(-none-)';
				checked = false;
				disabled = true;
			}
			else
			{
				html = '(' + numDefaults + ' different)';
				for (var i = 0; i < numDefaults; i++)
				{
					tooltip += Strings.encodeTags(defaultInfo['default'][i].name) + '\n';
				}
				checked = false;
			}
			
			currentDefaultDiv.title = tooltip;
			currentDefaultDiv.innerHTML = html;
			frm.replaceExistingDefault.checked = checked;
			frm.replaceExistingDefault.disabled = disabled;
		}
	}

	return protocols;
}();

Doc.onLoad(Protocols.initPage);
