/* $Id $
	------------------------------------------------------------------
	Copyright (C) 2013 Nicklas Nordborg

	This file is part of BASE - BioArray Software Environment.
	Available at http://base.thep.lu.se/

	BASE is free software; you can redistribute it and/or
	modify it under the terms of the GNU General Public License
	as published by the Free Software Foundation; either version 3
	of the License, or (at your option) any later version.

	BASE is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with BASE. If not, see <http://www.gnu.org/licenses/>.
	------------------------------------------------------------------

	@author Nicklas
*/

var AnalysisTree = function()
{
	var analysistree = {};
	
	/**
		Initialize the page.
	*/
	analysistree.initPage = function()
	{
		var experimentId = Data.get('tree-data', 'experiment-id');
		var bioAssaySetId = Data.get('tree-data', 'bioassayset-id');
		var transformationId = Data.get('tree-data', 'transformation-id');
		
		var attributes = {'item-type': 'BIOASSAYSET', 'extra-url': '&experiment_id='+experimentId};
		var tableAttributes = {'table-id': 'bioAssaySets'};
		
		Buttons.addClickHandler('btnNewRootBioAssaySet', Buttons.newItem, attributes);
		Buttons.addClickHandler('btnDeleteTreeItems', analysistree.deleteItems);
		Buttons.addClickHandler('btnRestoreTreeItems', Buttons.restoreItems, tableAttributes);
		Buttons.addClickHandler('btnTreeColumns', Buttons.configureColumns, tableAttributes);
		Buttons.addClickHandler('btnTreeExport', Buttons.runListPlugin, tableAttributes);
		Buttons.addClickHandler('btnTreeImport', Buttons.runListPlugin, tableAttributes);
		Buttons.addClickHandler('btnTreeRunPlugin', Buttons.runListPlugin, tableAttributes);

		IconStore.addDefaultIcons();
		IconStore.addIconSet('BioAssaySet', 'bioassayset.png');
		IconStore.addIconSet('Transformation', 'transformation.png');
		IconStore.addIconSet('Filter', 'filter.png');
		IconStore.addIconSet('ExtraValue', 'extravalue.png');
		
		Events.addEventHandler('bioAssaySets', 'joust-expand', analysistree.onExpand);
		Joust2.draw('tree-data');
		
		Events.addEventHandler('reloadOnNotify', 'base-notify', App.reloadWindow);
	}
	
	analysistree.initElements = function(element, autoInit)
	{
		if (autoInit == 'bioassayset-plotter')
		{
			Buttons.addClickHandler(element, analysistree.openBioAssaySetPlotter);
		}
		else if (autoInit == 'experiment-explorer')
		{
			Buttons.addClickHandler(element, analysistree.openExperimentExplorer);
		}
		else if (autoInit == 'bioassayset-plugin')
		{
			Buttons.addClickHandler(element, analysistree.runPluginForBioAssaySet);
		}
		else if (autoInit == 'copy-job')
		{
			Buttons.addClickHandler(element, analysistree.copyJob);
		}
	}
	
	analysistree.deleteItems = function()
	{
		var frm = document.forms['bioAssaySets'];
		if (Table.checkIfSelected('bioAssaySets') == 0) return;
		
		if (Forms.numChecked(frm, /^X:/) > 0)
		{
			if (!confirm('Extra values are deleted immediately and cannot be restored. Do you want to continue?'))
			{
				return;
			}
		}
		frm.cmd.value = 'DeleteItems';
		frm.submit();
	}

	analysistree.openBioAssaySetPlotter = function(event)
	{
		var url = '../plotter/index.jsp?ID='+App.getSessionId();
		url += '&bioassayset_id='+Data.get(event.currentTarget, 'item-id');
		Dialogs.openPopup(url, 'Plotter', 1250, 700);
	}
	
	analysistree.openExperimentExplorer = function(event)
	{
		var url = '../explorer/view/index.jsp?ID='+App.getSessionId();
		url += '&bioassayset_id='+Data.get(event.currentTarget, 'item-id');
		location.href = url;
	}

	analysistree.runPluginForBioAssaySet = function(event)
	{
		var experimentId = Data.get('tree-data', 'experiment-id');
		Data.define(event.currentTarget, {'item-type': 'BIOASSAYSET', 'extra-url': '&experiment_id='+experimentId});
		Buttons.runPlugin(event);
	}
	
	analysistree.copyJob = function(event)
	{
		var url = '../../../common/plugin/index.jsp?ID='+App.getSessionId();
		url += '&cmd=CopyJob&job_id='+Data.get(event.currentTarget, 'job-id');
		url += '&item_type=BIOASSAYSET&context_type=LIST'
		Dialogs.openPopup(url, 'CopyJob', 750, 500);
	}
	
	analysistree.onExpand = function(event)
	{
		var menuItem = event.target.item;
		var frm = document.forms['bioAssaySets'];
		if (menuItem.isOpen)
		{
			analysistree.showChildren(menuItem);
			frm.closed.value = frm.closed.value.replace(','+menuItem.id+',', ',');
		}
		else
		{
			analysistree.hideChildren(menuItem);
			frm.closed.value += menuItem.id+',';
		}
		analysistree.sendClosedWithAjax();
	}
	
	analysistree.showChildren = function(menuItem)
	{
		if (!menuItem.children) return;
		for (var childNo = 0; childNo < menuItem.children.length; childNo++)
		{
			var child = menuItem.children[childNo];
			Doc.show('row.'+child.id);
			if (child.isOpen)
			{
				analysistree.showChildren(child);
			}
		}
	}

	analysistree.hideChildren = function(menuItem)
	{
		if (!menuItem.children) return;
		for (var childNo = 0; childNo < menuItem.children.length; childNo++)
		{
			var child = menuItem.children[childNo];
			Doc.hide('row.'+child.id);
			analysistree.hideChildren(child);			
		}
	}
	
	analysistree.sendClosedWithAjax = function()
	{
		var request = Ajax.getXmlHttpRequest();
		var frm = document.forms['bioAssaySets'];
		var url = '../bioassaysets/index.jsp?ID='+App.getSessionId();
		url += '&cmd=SetClosedWithAjax';
		request.open("POST", url, true);
		var postdata = 'closed=' + frm.closed.value;

		request.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
		request.setRequestHeader("Content-length", postdata.length);
		request.setRequestHeader("Connection", "close");
		request.send(postdata);
	}

	return analysistree;
}();

Doc.onLoad(AnalysisTree.initPage);
Doc.addElementInitializer(AnalysisTree.initElements);

